### Name: figAdd
### Title: Plot editing: Add
### Aliases: figTicks figGrid figLegend figAddReservoirs figAdd figAddFit
###   figAddCurve figAddText figAddArrow figAddBox
### Keywords: aplot color iplot

### ** Examples

    data(blatna)
    accessVar("blatna")
    setCex(1.5)

    ## figTicks and figGrid
    binary("Zr/Nb","Ba/La")
    figTicks(major=-0.5, minor=0.25,10,1,10,1)
    figGrid(,5,col="darkblue") # just y axis (second parameter)

    figRedraw()
    figGrid(2,5,col="darkblue")
    
    ## figLegend
    groupsByLabel("Suite")
    figLegend(x="bottomleft",bg="#AAAAAAAA") # Semitransparent
    
    ## figAddReservoirs
    # binary plots   
    binary("Zr/Nb","Ba/La")
    # Sun & McDonough mantle reservoirs, Taylor & McLennan 1995 Upper and Lower Crust
    reserv<-c("(MORB|OIB) McDonough","Upper Crust Taylor 1995","Lower Crust Taylor 1995") 
    reserv.names<-c("NMORB","EMORB","OIB","UCC","LCC") 
    figAddReservoirs(autoscale=TRUE,var.name="reservoirs.data",reserv.condition=reserv,labs=reserv.names)

    # ternary plots    
    plateExtract("Wood",1)
    reserv<-c("(MORB|OIB) McDonough","Upper Crust Taylor 1995","Lower Crust Taylor 1995") 
    reserv.names<-c("NMORB","EMORB","OIB","UCC","LCC") 
    figAddReservoirs(TRUE,"reservoirs.data",reserv.condition=reserv,labs=reserv.names)
    
    ternary("SiO2/10","MgO","FeOt")
    figAddReservoirs(var.name="idealmins.data",sample.names=c("Or","Bt","Ph")) 
    
    # spider plots
    spider(WR,"NMORB..Sun",field=TRUE,colour="gray",field.colour=TRUE,ymin=0.1,ymax=1000)
    figAddReservoirs(var.name="reservoirs.data",reserv.condition="Continental Crust",
        autoscale=TRUE,col=c("red","black","darkblue"),pch=1:3)
    
    # Calculate Rayleigh-type fractionation trend
    ff<-seq(1,0.1,-0.1) # F, amount of melt left
    x<-80*ff^(1.2-1)    # cL for three elements, arbitrary D of 1.2, 2.0 and 1.3
    y<-550*ff^(2.0-1)
    z<-1000*ff^(1.3-1)
    my.trend<-cbind(x,y,z)
    colnames(my.trend)<-c("Rb","Sr","Ba")
    rownames(my.trend)<-ff

    # By default, the overplotted information is added permanently    
    binary("Rb","Sr",log="xy")
    figAddReservoirs(var.name="my.trend",pch="+",col="blue",autoscale=TRUE,type="o",
        labs=rownames(my.trend))
    figXlim(c(10,500))

    # But this is controlled by the argument just.draw   
    binary("Rb","Sr",log="xy")
    figAddReservoirs(var.name="my.trend",pch="+",col="red",autoscale=TRUE,type="o",
        labs=rownames(my.trend),just.draw=TRUE)
    figRedraw() 



