### Name: figOverplot
### Title: Overplotting data onto pre-existing binary, ternary or spider
###   plots
### Aliases: figOverplot
### Keywords: aplot color iplot

### ** Examples

    data(sazava)
    accessVar("sazava")

    setCex(1.5)
    pokeDataset("sazava", overwrite.warn=FALSE)
    
    # Calculate Rayleigh-type fractionation trend
    ff<-seq(1,0.1,-0.1) # F, amount of melt left
    x<-80*ff^(1.2-1)    # cL for three elements, arbitrary D of 1.2, 2.0 and 1.3
    y<-550*ff^(2.0-1)
    z<-1000*ff^(1.3-1)
    my.trend<-cbind(x,y,z)
    colnames(my.trend)<-c("Rb","Sr","Ba")
    rownames(my.trend)<-ff

    # By default, the overplotted information is added permanently    
    binary("Rb","Sr",log="xy")
    figOverplot(var.name="my.trend",pch="+",col="blue",autoscale=TRUE,type="o",
        labs=rownames(my.trend))
    figXlim(c(30,100))

    # But this is controlled by the argument just.draw    
    binary("Rb","Sr",log="xy")
    figOverplot(var.name="my.trend",pch="+",col="darkred",autoscale=TRUE,type="o",
        labs=rownames(my.trend),just.draw=TRUE)
    # Any function redrawing the plotting window will wipe the added trend out
    figXlim(c(30,100))
    
    # Ternary
    ternary("10*Rb","2*Sr","Ba/2")
    figOverplot(var.name="my.trend",pch="+",col="blue",type="o",
        labs=rownames(my.trend))



