### Name: spider
### Title: Spider plot(s): Selected samples
### Aliases: spiderplot.r spider spider.individual spider.contour
### Keywords: hplot

### ** Examples

    data(blatna)
    accessVar("blatna")
    
    ee<-spider.contour("Boynton","SiO2","reds",pch="*",cex=1.5,ymin=0.01,ymax=1000)
    # ee<- redirects the output 
    
    spider(WR,"Boynton",0.1,1000,pch="*",col="red",cex=2,join=FALSE) 

    spider(WR[1:11,],"Boynton",1,500,pch=1:11,col=1:11,legend=TRUE)

    spider(WR,"Boynton",field=TRUE,density=0.02,angle=60,col="darkred",fill.col=FALSE,0.1,1000)

    spider(WR,"Boynton",field=TRUE,fill.col=TRUE,shaded.col="khaki",0.1,1000)
        
    # Shade the background field portraying the overall variation 
    spider(WR,"Boynton",0.1,1000)
    spider(WR,"Boynton",field=TRUE,fill.col=TRUE,shaded.col="gray",add=TRUE)

    spider(WR,"Boynton",0.1,1000)
    spider(WR,"Boynton",field=TRUE,density=0.02,angle=45,col="gray",fill.col=FALSE,add=TRUE)

    # Custom normalization scheme
    chon<-c(0.4,4,50,0.8,0.7,10,35,9,340,9,70,8.0)
    chon<-matrix(chon,nrow=1)
    colnames(chon)<-c("K2O","Rb","Ba","Th","Ta","Nb","Ce","Hf","Zr","Sm","Y","Yb")
    rownames(chon)<-"ORG (Pearce et al. 1984)"
    spider(WR,chon,ymin=0.01,col="navy",ymax=1000)

    # Possible styles for x axis
    multiplePerPage(8,nrow=2,ncol=4,"Possible x axis styles", dummy=FALSE)
    spider(WR, "Boynton", 0.1, 1000, 
        offset=FALSE, xrotate=FALSE, centered=FALSE, 
        main="offset=FALSE, xrotate=FALSE, centered=FALSE",new=FALSE)
    spider(WR, "Boynton", 0.1, 1000, 
        offset=FALSE, xrotate=TRUE, centered=FALSE, 
        main="offset=FALSE, xrotate=TRUE, centered=FALSE",new=FALSE)
    spider(WR, "Boynton", 0.1, 1000, 
        offset=FALSE, xrotate=FALSE, centered=TRUE, 
        main="offset=FALSE, xrotate=FALSE, centered=TRUE",new=FALSE)
    spider(WR, "Boynton", 0.1, 1000, 
        offset=FALSE, xrotate=TRUE, centered=TRUE, 
        main="offset=FALSE, xrotate=TRUE, centered=TRUE",new=FALSE)
    spider(WR, "Boynton", 0.1, 1000, 
        offset=TRUE, xrotate=FALSE, centered=FALSE, 
        main="offset=TRUE, xrotate=FALSE, centered=FALSE",new=FALSE)
    spider(WR, "Boynton", 0.1, 1000, 
        offset=TRUE, xrotate=TRUE, centered=FALSE, 
        main="offset=TRUE, xrotate=TRUE, centered=FALSE",new=FALSE)
    spider(WR, "Boynton", 0.1, 1000, 
        offset=TRUE, xrotate=FALSE, centered=TRUE, 
        main="offset=TRUE, xrotate=FALSE, centered=TRUE",new=FALSE)
    spider(WR, "Boynton", 0.1, 1000, 
        offset=TRUE, xrotate=TRUE, centered=TRUE, 
        main="offset=TRUE, xrotate=TRUE, centered=TRUE",new=FALSE)
    plateCexLab(1.5)
    plateRedraw()
    
    spider(WR,"Boynton",plot=FALSE) # Calculation only
    print(results)



